ML Launchpad documentation
==============================================================================
ML Launchpad is an extensible Python package which makes it easy to publish Machine Learning models as RESTful APIs.

It separates the Machine Learning side (how to train, test and to predict) from the environment-specific aspects (local or cloud deployment of the API, database connections, format validation, model storage, etc.).

Contents:

.. toctree::
   :maxdepth: 2

   readme
   about
   installation
   usage
   mllaunchpad
   config
   DataSources <datasources>
   contributing
   Code of Conduct <conduct>
   authors
   changelog

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
